@@ -171,13 +171,14 @@ pref("mail.file_attach_binary",             false);
 pref("mail.show_headers",                   1); // some
 pref("mail.pane_config",                    0);
 pref("mail.addr_book.mapit_url.format", "chrome://messenger-region/locale/region.properties");
-//@line 175 "/data/mozbuild/releases/seamonkey-1.1.1/mozilla/mailnews/mailnews.js"
+//@line 175 "/data/mozbuild/releases/seamonkey-1.1.4/build/mailnews/../../mozilla/mailnews/mailnews.js"
+pref("mailnews.start_page.url", "chrome://messenger-region/locale/region.properties");
 pref("mail.addr_book.im.onlineCheckAllowed", false);
 pref("messenger.throbber.url","chrome://messenger-region/locale/region.properties");
 pref("compose.throbber.url","chrome://messenger-region/locale/region.properties");
 pref("addressbook.throbber.url","chrome://messenger-region/locale/region.properties");
 pref("mail.accountwizard.deferstorage", false);
-//@line 181 "/data/mozbuild/releases/seamonkey-1.1.1/mozilla/mailnews/mailnews.js"
+//@line 182 "/data/mozbuild/releases/seamonkey-1.1.4/build/mailnews/../../mozilla/mailnews/mailnews.js"
 
 // the format for "mail.addr_book.quicksearchquery.format" is:
 // @V == the escaped value typed in the quick search bar in the addressbook
@@ -394,7 +395,6 @@ pref("mailnews.reuse_message_window", true);
 pref("mailnews.reuse_thread_window2", false);
 pref("mailnews.open_window_warning", 10); // warn user if they attempt to open more than this many messages at once
 
-pref("mailnews.start_page.url", "chrome://messenger-region/locale/region.properties");
 pref("mailnews.start_page.enabled", true);
 
 pref("mailnews.remember_selected_message", true);
@@ -634,6 +634,8 @@ pref("mail.server.default.retainBy", 1);
 pref("mailnews.ui.junk.firstuse", true);
 pref("mailnews.ui.junk.manualMarkAsJunkMarksRead", true);
 
+pref("mailnews.use_received_date", false);
+
 // for manual upgrades of certain UI features.
 // 1 -> 2 is for the folder pane tree landing, to hide the
 // unread and total columns, see msgMail3PaneWindow.js
@@ -727,9 +729,9 @@ pref("mail.standalone", false);
 // the users last used preference.
 pref("mailnews.import.text.skipfirstrecord", true);
 
-//@line 737 "/data/mozbuild/releases/seamonkey-1.1.1/mozilla/mailnews/mailnews.js"
+//@line 739 "/data/mozbuild/releases/seamonkey-1.1.4/build/mailnews/../../mozilla/mailnews/mailnews.js"
 
-//@line 740 "/data/mozbuild/releases/seamonkey-1.1.1/mozilla/mailnews/mailnews.js"
+//@line 742 "/data/mozbuild/releases/seamonkey-1.1.4/build/mailnews/../../mozilla/mailnews/mailnews.js"
 pref("mail.empty_trash", false);
 
 pref("mail.check_new_mail", true);
@@ -746,5 +748,5 @@ pref("news.show_first_unread", false);
 pref("news.sash_geometry", "");
 pref("mail.signature_date", 0);
 
-//@line 759 "/data/mozbuild/releases/seamonkey-1.1.1/mozilla/mailnews/mailnews.js"
+//@line 761 "/data/mozbuild/releases/seamonkey-1.1.4/build/mailnews/../../mozilla/mailnews/mailnews.js"
 
